intelmq.bots.collectors.fireeye package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.fireeye package

## Submodules

## intelmq.bots.collectors.fireeye.collector_mas module

Fireeye collector bot

Parameters: http_username, http_password: string http_timeout_max_tries: an integer depicting how often a connection attempt is retried host : dns name of the local appliance request_duration: how old date should be fetched eg 24_hours or 48_hours

`intelmq.bots.collectors.fireeye.collector_mas.` `BOT`

  alias of `intelmq.bots.collectors.fireeye.collector_mas.FireeyeMASCollectorBot`

class `intelmq.bots.collectors.fireeye.collector_mas.` `FireeyeMASCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`, `intelmq.lib.mixins.http.HttpMixin`

  `host`: str = None
  `http_password`: str = None
  `http_username`: str = None
  `init`()
  `process`()
  `request_duration`: str = None
  `xml_processor`(uuid, token, new_report, host, product)

## Module contents